@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Release;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.22';
+our $VERSION = '0.93';
 
 =head1 NAME
 
@@ -43,11 +43,19 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 relation_lists()
 
+=head2 tag_list()
+
+=head2 user_tag_list()
+
+=head2 rating()
+
+=head2 user_rating()
+
 =head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id type title text_rep_language text_rep_script asin artist release_event_list disc_list puid_list track_list relation_list relation_lists score/);
+__PACKAGE__->mk_accessors(qw/id type title text_rep_language text_rep_script asin artist release_group release_event_list disc_list puid_list track_list relation_list relation_lists tag_list user_tag_list rating user_rating score/);
 
 =head1 AUTHOR
 
@@ -59,7 +67,7 @@ __PACKAGE__->mk_accessors(qw/id type title text_rep_language text_rep_script asi
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2007 by Bob Faist
+Copyright 2006-2009 by Bob Faist
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
